# eric7.WebBrowser.Passwords.PasswordManager

Module implementing the password manager.

### Global Attributes

None

### Classes

PasswordManager | Class implementing the password manager.

### Functions

None

## PasswordManager

Class implementing the password manager.

### Signals

changed()
  emitted to indicate a change
passwordsSaved()
  emitted after the passwords were saved

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

PasswordManager | Constructor
__createKey | Private method to create the key string for the login credentials.
__load | Private method to load the saved login credentials.
__stripUrl | Private method to strip off all unneeded parts of a URL.
allSiteNames | Public method to get a list of all site names.
clear | Public slot to clear the saved passwords.
close | Public method to close the passwords manager.
completePage | Public slot to complete login forms with saved data.
formSubmitted | Public method to record login data.
getFileName | Public method to get the file name of the passwords file.
getLogin | Public method to get the login credentials.
mainPasswordChanged | Public slot to handle the change of the main password.
reload | Public method to reload the login data.
removePassword | Public method to remove a password entry.
save | Public slot to save the login entries to disk.
setLogin | Public method to set the login credentials.
siteInfo | Public method to get a reference to the named site.
sitesCount | Public method to get the number of available sites.

### Static Methods

None

#### PasswordManager (Constructor)

PasswordManager(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### PasswordManager.__createKey

__createKey(url, realm)

Private method to create the key string for the login credentials.

url (QUrl)
  URL to get the credentials for
realm (str)
  realm to get the credentials for

Return:
  key string

Return Type:
  str

#### PasswordManager.__load

__load()

Private method to load the saved login credentials.

#### PasswordManager.__stripUrl

__stripUrl(url)

Private method to strip off all unneeded parts of a URL.

url (QUrl)
  URL to be stripped

Return:
  stripped URL

Return Type:
  QUrl

#### PasswordManager.allSiteNames

allSiteNames()

Public method to get a list of all site names.

Return:
  sorted list of all site names

Return Type:
  list of str

#### PasswordManager.clear

clear()

Public slot to clear the saved passwords.

#### PasswordManager.close

close()

Public method to close the passwords manager.

#### PasswordManager.completePage

completePage(page)

Public slot to complete login forms with saved data.

page (WebBrowserPage)
  reference to the web page

#### PasswordManager.formSubmitted

formSubmitted(urlStr, userName, password, data, page)

Public method to record login data.

urlStr (str)
  form submission URL
userName (str)
  name of the user
password (str)
  user password
data (QByteArray)
  data to be submitted
page (QWebEnginePage)
  reference to the calling page

#### PasswordManager.getFileName

getFileName()

Public method to get the file name of the passwords file.

Return:
  name of the passwords file

Return Type:
  str

#### PasswordManager.getLogin

getLogin(url, realm)

Public method to get the login credentials.

url (QUrl)
  URL to get the credentials for
realm (str)
  realm to get the credentials for

Return:
  tuple containing the user name (string) and password

Return Type:
  str

#### PasswordManager.mainPasswordChanged

mainPasswordChanged(oldPassword, newPassword)

Public slot to handle the change of the main password.

oldPassword (str)
  current main password
newPassword (str)
  new main password

#### PasswordManager.reload

reload()

Public method to reload the login data.

#### PasswordManager.removePassword

removePassword(site)

Public method to remove a password entry.

site (str)
  web site name

#### PasswordManager.save

save()

Public slot to save the login entries to disk.

#### PasswordManager.setLogin

setLogin(url, realm, username, password)

Public method to set the login credentials.

url (QUrl)
  URL to set the credentials for
realm (str)
  realm to set the credentials for
username (str)
  username for the login
password (str)
  password for the login

#### PasswordManager.siteInfo

siteInfo(site)

Public method to get a reference to the named site.

site (str)
  web site name

Return:
  tuple containing the user name (string) and password

Return Type:
  str

#### PasswordManager.sitesCount

sitesCount()

Public method to get the number of available sites.

Return:
  number of sites

Return Type:
  int

Up